Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func HandleOutput ¶
Types ¶
type Utils ¶
type Utils struct {
Cfg *config.Config
Logger *slog.Logger
Output string
// contains filtered or unexported fields
}
func (*Utils) GetAPIClient ¶
func (*Utils) HandleResponse ¶
handleResponse processes the API response. If it's an error, it returns an error with the body content. If it's a success, it returns nil so the caller can proceed with decoding.
Click to show internal directories.
Click to hide internal directories.